@@ -364,7 +364,7 @@ class ApplicationMenu(CoreApplicationMenu):
         progress.update(0)
         # add "All" category
         self.all_category_name = "<b>%s</b>" % _("All")
-        item = Category(self, self.all_category_name, "distributor-logo")
+        item = Category(self, self.all_category_name, "trisquel")
         self.all_category_iter = self.real_categories_store.push_back(item)
         self.initListStores(item, self)
         # now go for the categories
