@@ -227,11 +227,10 @@ class CodecSearchActivationStyle(SearchActivationStyle):
 
         app.textview_description.show_message("",
                                               _("Some countries allow patents on software, and freely "
-                                                "redistributable software like Ubuntu cannot pay for patent "
-                                                "licenses. If you are in "
-                                                "one of these jurisdictions, you can buy licensed media playback "
-                                                "plug-ins from the Canonical Store. Otherwise, select a free "
-                                                "plug-in above to install it."))
+                                                "redistributable software like Trisquel will not distribute "
+                                                "patent-encumbered software. If you are in one of these "
+                                                "jurisdictions, please select an alternative free plug-in "
+                                                "above to install it."))
         app.button_help.hide()
         app.treeview_packages.set_headers_visible(False)
         app.treeview_packages.column_app_popcon.set_visible(False)
